@@ -18,7 +18,7 @@ my(@XSStack);	# Stack of conditionals and INCLUDEs
 my($XSS_work_idx, $cpp_next_tmp);
 
 use vars qw($VERSION);
-$VERSION = '2.200401';
+$VERSION = '2.200402';
 
 use vars qw(%input_expr %output_expr $ProtoUsed @InitFileCode $FH $proto_re $Overload $errors $Fallback
 	    $cplusplus $hiertype $WantPrototypes $WantVersionChk $except $WantLineNumbers
@@ -555,7 +555,6 @@ EOF
       my $arg0 = ((defined($static) or $func_name eq 'new')
 		  ? "CLASS" : "THIS");
       unshift(@args, $arg0);
-#      ($report_args = "$arg0, $report_args") =~ s/^\w+, $/$arg0/;
     }
     my $extra_args = 0;
     @args_num = ();
@@ -979,8 +978,6 @@ EOF
   #Under 5.8.x and lower, newXS is declared in proto.h as expecting a non-const
   #file name argument. If the wrong qualifier is used, it causes breakage with
   #C++ compilers and warnings with recent gcc.
-  my $file_decl = ($] < 5.009) ? "char file[]" : "const char* file";
-
   #-Wall: if there is no $Full_func_name there are no xsubs in this .xs
   #so `file' is unused
   print Q(<<"EOF") if $Full_func_name;
@@ -1036,7 +1033,7 @@ EOF
   }
 
   print Q(<<'EOF');
-##ifdef PL_unitcheckav
+##if (PERL_REVISION == 5 && PERL_VERSION >= 9)
 #  if (PL_unitcheckav)
 #       call_list(PL_scopestack_ix, PL_unitcheckav);
 ##endif
